==> jc-1.4.0.tar.gz: java/awt/PageAttributes__24PrintQualityType.h <==
// public final class java.awt.PageAttributes$PrintQualityType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 5d77f3e406c449c2 java_awt_PageAttributes__24PrintQualityType
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_PageAttributes__24PrintQualityType_H_
#define _JC_java_awt_PageAttributes__24PrintQualityType_H_

// Forward structure declarations
struct _jc_java_awt_PageAttributes__24PrintQualityType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_PageAttributes__24PrintQualityType$sub_refs	_jc_java_awt_PageAttributes__24PrintQualityType$sub_refs;
typedef struct _jc_java_awt_PageAttributes__24PrintQualityType$sub_nonrefs	_jc_java_awt_PageAttributes__24PrintQualityType$sub_nonrefs;
typedef struct _jc_java_awt_PageAttributes__24PrintQualityType$refs	_jc_java_awt_PageAttributes__24PrintQualityType$refs;
typedef struct _jc_java_awt_PageAttributes__24PrintQualityType$nonrefs	_jc_java_awt_PageAttributes__24PrintQualityType$nonrefs;
typedef struct _jc_java_awt_PageAttributes__24PrintQualityType$object	_jc_java_awt_PageAttributes__24PrintQualityType$object;

typedef struct _jc_java_awt_PageAttributes__24PrintQualityType$fields_struct	_jc_java_awt_PageAttributes__24PrintQualityType$fields_struct;
typedef const struct _jc_java_awt_PageAttributes__24PrintQualityType$vmethods	_jc_java_awt_PageAttributes__24PrintQualityType$vmethods;
typedef const struct _jc_java_awt_PageAttributes__24PrintQualityType$vtable	_jc_java_awt_PageAttributes__24PrintQualityType$vtable;
typedef const struct _jc_java_awt_PageAttributes__24PrintQualityType$vtype	_jc_java_awt_PageAttributes__24PrintQualityType$vtype;

// Class fields structure
struct _jc_java_awt_PageAttributes__24PrintQualityType$fields_struct {
	struct _jc_java_awt_PageAttributes__24PrintQualityType$object	*DRAFT;
	struct _jc_java_awt_PageAttributes__24PrintQualityType$object	*HIGH;
	_jc_object_array	*NAMES;
	struct _jc_java_awt_PageAttributes__24PrintQualityType$object	*NORMAL;
};
extern _jc_java_awt_PageAttributes__24PrintQualityType$fields_struct _jc_java_awt_PageAttributes__24PrintQualityType$class_fields;

// Constructors
extern void _jc_java_awt_PageAttributes__24PrintQualityType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_PageAttributes__24PrintQualityType$object *, jint);

// Static methods
extern void _jc_java_awt_PageAttributes__24PrintQualityType$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_PageAttributes__24PrintQualityType$vmethods {
};

// Vtable
struct _jc_java_awt_PageAttributes__24PrintQualityType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_PageAttributes__24PrintQualityType$vmethods	java_awt_PageAttributes__24PrintQualityType;
};

// Vtype
struct _jc_java_awt_PageAttributes__24PrintQualityType$vtype {
	_jc_type			type;
	_jc_java_awt_PageAttributes__24PrintQualityType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24PrintQualityType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_PageAttributes__24PrintQualityType$refs {
    _jc_java_awt_PageAttributes__24PrintQualityType$sub_refs	java_awt_PageAttributes__24PrintQualityType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24PrintQualityType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_PageAttributes__24PrintQualityType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_PageAttributes__24PrintQualityType$sub_nonrefs	java_awt_PageAttributes__24PrintQualityType;
};

// Object instance structure
struct _jc_java_awt_PageAttributes__24PrintQualityType$object {
	_jc_java_awt_PageAttributes__24PrintQualityType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_PageAttributes__24PrintQualityType$vtype	*vtype;
	_jc_java_awt_PageAttributes__24PrintQualityType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_PageAttributes__24PrintQualityType$vtype _jc_java_awt_PageAttributes__24PrintQualityType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_PageAttributes__24PrintQualityType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_PageAttributes__24PrintQualityType$class_object;

#endif	/* _JC_java_awt_PageAttributes__24PrintQualityType_H_ */

==> jc-1.4.6.tar.gz: java/awt/PageAttributes__24PrintQualityType.h <==
// public final class java.awt.PageAttributes$PrintQualityType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 5d77f3e406c449c2 java_awt_PageAttributes__24PrintQualityType
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_PageAttributes__24PrintQualityType_H_
#define _JC_java_awt_PageAttributes__24PrintQualityType_H_

// Forward structure declarations
struct _jc_java_awt_PageAttributes__24PrintQualityType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_PageAttributes__24PrintQualityType$sub_refs	_jc_java_awt_PageAttributes__24PrintQualityType$sub_refs;
typedef struct _jc_java_awt_PageAttributes__24PrintQualityType$sub_nonrefs	_jc_java_awt_PageAttributes__24PrintQualityType$sub_nonrefs;
typedef struct _jc_java_awt_PageAttributes__24PrintQualityType$refs	_jc_java_awt_PageAttributes__24PrintQualityType$refs;
typedef struct _jc_java_awt_PageAttributes__24PrintQualityType$nonrefs	_jc_java_awt_PageAttributes__24PrintQualityType$nonrefs;
typedef struct _jc_java_awt_PageAttributes__24PrintQualityType$object	_jc_java_awt_PageAttributes__24PrintQualityType$object;

typedef struct _jc_java_awt_PageAttributes__24PrintQualityType$fields_struct	_jc_java_awt_PageAttributes__24PrintQualityType$fields_struct;
typedef const struct _jc_java_awt_PageAttributes__24PrintQualityType$vmethods	_jc_java_awt_PageAttributes__24PrintQualityType$vmethods;
typedef const struct _jc_java_awt_PageAttributes__24PrintQualityType$vtable	_jc_java_awt_PageAttributes__24PrintQualityType$vtable;
typedef const struct _jc_java_awt_PageAttributes__24PrintQualityType$vtype	_jc_java_awt_PageAttributes__24PrintQualityType$vtype;

// Class fields structure
struct _jc_java_awt_PageAttributes__24PrintQualityType$fields_struct {
	struct _jc_java_awt_PageAttributes__24PrintQualityType$object	*DRAFT;
	struct _jc_java_awt_PageAttributes__24PrintQualityType$object	*HIGH;
	_jc_object_array	*NAMES;
	struct _jc_java_awt_PageAttributes__24PrintQualityType$object	*NORMAL;
};
extern _jc_java_awt_PageAttributes__24PrintQualityType$fields_struct _jc_java_awt_PageAttributes__24PrintQualityType$class_fields;

// Constructors
extern void _jc_java_awt_PageAttributes__24PrintQualityType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_PageAttributes__24PrintQualityType$object *, jint) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_awt_PageAttributes__24PrintQualityType$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_PageAttributes__24PrintQualityType$vmethods {
};

// Vtable
struct _jc_java_awt_PageAttributes__24PrintQualityType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_PageAttributes__24PrintQualityType$vmethods	java_awt_PageAttributes__24PrintQualityType;
};

// Vtype
struct _jc_java_awt_PageAttributes__24PrintQualityType$vtype {
	_jc_type			type;
	_jc_java_awt_PageAttributes__24PrintQualityType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24PrintQualityType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_PageAttributes__24PrintQualityType$refs {
    _jc_java_awt_PageAttributes__24PrintQualityType$sub_refs	java_awt_PageAttributes__24PrintQualityType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_PageAttributes__24PrintQualityType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_PageAttributes__24PrintQualityType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_PageAttributes__24PrintQualityType$sub_nonrefs	java_awt_PageAttributes__24PrintQualityType;
};

// Object instance structure
struct _jc_java_awt_PageAttributes__24PrintQualityType$object {
	_jc_java_awt_PageAttributes__24PrintQualityType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_PageAttributes__24PrintQualityType$vtype	*vtype;
	_jc_java_awt_PageAttributes__24PrintQualityType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_PageAttributes__24PrintQualityType$vtype _jc_java_awt_PageAttributes__24PrintQualityType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_PageAttributes__24PrintQualityType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_PageAttributes__24PrintQualityType$class_object;

#endif	/* _JC_java_awt_PageAttributes__24PrintQualityType_H_ */
